/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import angular from 'angular';
/**
 * Take text from the model and present it to the user as a string
 * @param {text} model value
 * @returns {string}
 */
export function toUser(text) {
    if (text == null) {
        return '';
    }
    if (typeof text === 'object') {
        if (text.match_all) {
            return '';
        }
        if (text.query_string) {
            return toUser(text.query_string.query);
        }
        return angular.toJson(text);
    }
    return '' + text;
}
